﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web.Http;
using ProductStore.Models;

namespace ProductStore.Controllers
{
    public class ProductsController : ApiController
    {
        private static readonly IProductRepository _repository = new ProductRepository();

        public IEnumerable<Product> GetAllProducts()
        {
            return _repository.GetAll();
        }

        public Product GetProduct(int id)
        {
            Product item = _repository.Get(id);
            if (item == null)
            {
                throw new HttpResponseException(HttpStatusCode.NotFound);
            }
            return item;
        }

        public IEnumerable<Product> GetProductsByCategory(string category)
        {
            return _repository.GetAll().Where(
                p => string.Equals(p.Category, category, StringComparison.OrdinalIgnoreCase));
        }

        public HttpResponseMessage PostProduct(Product item)
        {
            item = _repository.Add(item);
            var response = Request.CreateResponse(HttpStatusCode.Created, item);

            string uri = Url.Link("DefaultApi", new { id = item.Id });
            if (uri != null) {
                response.Headers.Location = new Uri(uri);
            }
            return response;
            //return CreatedAtRoute("DefaultApi", new { id = item.Id }, item);
        }

        public void PutProduct(Product product)
        {
            if (!_repository.Update(product))
            {
                throw new HttpResponseException(HttpStatusCode.NotFound);
            }
        }

        public void DeleteProduct(int id)
        {
            bool isDeleted = _repository.Remove(id);
            if (!isDeleted)
            {
                throw new HttpResponseException(HttpStatusCode.NotFound);
            }
        }
        //public HttpResponseMessage DeleteProduct(int id)
        //{
        //    bool isDeleted = _repository.Remove(id);
        //    if (!isDeleted) {
        //        throw new HttpResponseException(HttpStatusCode.NotFound);
        //    }
        //    return Request.CreateResponse(HttpStatusCode.OK, "OK!");
        //}
    }
}
